==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Príslušenstvo vrátené',
    'Accessory_Checkout_Notification' => 'Príslušenstvo odovzdané',
    'Asset_Checkin_Notification' => 'Majetok vrátený',
    'Asset_Checkout_Notification' => 'Majetok odovzdaný',
    'Confirm_Accessory_Checkin' => 'Potvrdenie vrátenia príslušenstva',
    'Confirm_Asset_Checkin' => 'Potvrdenie vrátenia majetku',
    'Confirm_accessory_delivery' => 'Potvrdenie odovzdania príslušenstva',
    'Confirm_asset_delivery' => 'Potvrdenie odovzdania majetku',
    'Confirm_consumable_delivery' => 'Potvrdenie odovzdania spotrebného materiálu',
    'Confirm_license_delivery' => 'Potvrdenie priradenia licencie',
    'Consumable_checkout_notification' => 'Spotrebný materiál odovzdaný',
    'Days' => 'Dni',
    'Expected_Checkin_Date' => 'Majetok, ktorý vám bol odovzdaný, musí byť vrátený späť do :date',
    'Expected_Checkin_Notification' => 'Pripomienka: Termín na vrátenie :name sa blíži',
    'Expected_Checkin_Report' => 'Report očakávaných návratov majetku',
    'Expiring_Assets_Report' => 'Report majetku s končiacou zárukou.',
    'Expiring_Licenses_Report' => 'Report exspirujúcich licencií.',
    'Item_Request_Canceled' => 'Požiadavka na položku zrušená',
    'Item_Requested' => 'Položka vyžiadaná',
    'License_Checkin_Notification' => 'Licencia odobratá',
    'License_Checkout_Notification' => 'Licencie priradená',
    'license_for'   => 'Licencia pre',
    'Low_Inventory_Report' => 'Report nízkych zásob',
    'a_user_canceled' => 'Používateľ zrušil žiadosť o položku na webe',
    'a_user_requested' => 'Používateľ vytvorit žiadosť o položku na webe',
    'acceptance_asset_accepted' => 'Používateľ potvrdil prijatie položky',
    'acceptance_asset_declined' => 'Používateľ zamietol prijatie položky',
    'accessory_name' => 'Názov príslušenstva',
    'additional_notes' => 'Ďalšie poznámky',
    'admin_has_created' => 'Administrátor pre vás vytvoril účet na stránke :web.',
    'asset' => 'Majetok',
    'asset_name' => 'Názov majetku',
    'asset_requested' => 'Vyžiadaný majetok',
    'asset_tag' => 'Označenie majetku',
    'assets_warrantee_alert' => 'Existuje :count položka majetku, ktorej končí záruka v najbližších :threshold dňoch.|Existuje :count položiek majetku, ktorým končí záruka v najbližších :threshold dňoch.',
    'assigned_to' => 'Pridelené',
    'best_regards' => 'S pozdravom,',
    'canceled' => 'Zrušené',
    'checkin_date' => 'Dátum vrátenia',
    'checkout_date' => 'Dátum odovzdania',
    'checkedout_from' => 'Odovzadené',
    'checkedin_from'  => 'Prijaté od',
    'checked_into' => 'Priradené do',
    'click_on_the_link_accessory' => 'Prosím kliknite na nižšie priložený odkaz pre potvrdenie prevzatia príslušenstva.',
    'click_on_the_link_asset' => 'Prosím kliknite na nižšie priložený odkaz pre potvrdenie prevzatia majetku.',
    'click_to_confirm' => 'Prosím kliknite na nasledujúci odkaz pre potvrdenie vášho :web účtu:',
    'current_QTY' => 'Aktuálne množstvo',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očakávaný dátum vrátenia',
    'expires' => 'Exspiruje',
    'hello' => 'Ahoj',
    'hi' => 'Ahoj',
    'i_have_read' => 'Súhlasím s podmienkami používania, potvrdzujem prevzatie položky.',
    'inventory_report' => 'Report majetku',
    'item' => 'Položka',
    'item_checked_reminder' => 'Toto je pripomienka, že vám boli odovzdané :count položky, ktorých prijatie ste nepotvrdili a ani neodmietli. Prosím kliknite na odkaz nižšie pre potvrdenie vašej voľby.',
    'license_expiring_alert' => 'V nasledujúcich :threshold dňoch exspiruje :count licencia.|V nasledujúcich :threshold dňoch exspirujú :count licencie.',
    'link_to_update_password' => 'Prosím kliknite na nasledovný odkaz pre zmenu hesla na stránke :web :',
    'login' => 'Prihlásenie',
    'login_first_admin' => 'Prihláste sa do vašej novej Snipe-IT inštalácie s použitím prihlasovacích údajov:',
    'low_inventory_alert' => 'Existuje :count položka, ktorá je alebo čoskoro bude pod hranicou minimálnych skladových zásob.|Existuje :count položiek, ktoré sú alebo čoskoro budú pod hranicou minimálnych skladových zásob.',
    'min_QTY' => 'Minimálne množstvo',
    'name' => 'Názov',
    'new_item_checked' => 'Nová položka bola odovzdaná pod vašim menom, podrobnosti sú uvedené nižšie.',
    'notes' => 'Poznámky',
    'password' => 'Heslo',
    'password_reset' => 'Reset hesla',
    'read_the_terms' => 'Prosím prečítajte si nižšie uvedené podmienky používania.',
    'read_the_terms_and_click' => 'Prosím prečítajte si nižšie uvedené podmienky používania a kliknite na odkaz v dolnej časti pre potvrdenie, že ste si prečítali a súhlasili s podmienkami používania a prevzali majetok.',
    'requested' => 'Vyžiadané',
    'reset_link' => 'Váš odkaz na resetovanie hesla',
    'reset_password' => 'Kliknite sem pre resetovanie vášho hesla:',
    'rights_reserved' => 'Všetky práva vyhradené.',
    'serial' => 'Sériové číslo',
    'snipe_webhook_test' => 'Snipe-IT integračný test',
    'snipe_webhook_summary' => 'Snipe-IT výsledok integračného testu',
    'supplier' => 'Dodávateľ',
    'tag' => 'Značka',
    'test_email' => 'Testovací mail zo Snipe-IT',
    'test_mail_text' => 'Toto je test odoslaný zo Snipe-IT Asset Manažmentu. Všetko funguje, ak ste obdržali tento mail :)',
    'the_following_item' => 'Nasledujúca položka bola vrátená: ',
    'to_reset' => 'Pre resetovanie vášho :web hesla, prosím vyplňte nasledujúci formulár:',
    'type' => 'Typ',
    'upcoming-audits' => 'Existuje :count položka, ktorá bude podliehať auditu v priebehu :threshold dní.|Existujú :count položky, ktoré budú podliehať auditu v priebehu :threshold dní.',
    'user' => 'Používateľ',
    'username' => 'Používateľské meno',
    'unaccepted_asset_reminder' => 'Nepotvrdili ste prevzatie majetku.',
    'welcome' => 'Vitaj :name',
    'welcome_to' => 'Vitaj na :web!',
    'your_assets' => 'Zobraziť vaše položky majetku',
    'your_credentials' => 'Vaše Snipe-IT prihlasovacie údaje',
    'mail_sent' => 'Mail bol úspešne odoslaný!',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sk-SK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Príslušenstvo vrátené',
    'Accessory_Checkout_Notification' => 'Príslušenstvo odovzdané',
    'Asset_Checkin_Notification' => 'Majetok vrátený',
    'Asset_Checkout_Notification' => 'Majetok odovzdaný',
    'Confirm_Accessory_Checkin' => 'Potvrdenie vrátenia príslušenstva',
    'Confirm_Asset_Checkin' => 'Potvrdenie vrátenia majetku',
    'Confirm_accessory_delivery' => 'Potvrdenie odovzdania príslušenstva',
    'Confirm_asset_delivery' => 'Potvrdenie odovzdania majetku',
    'Confirm_consumable_delivery' => 'Potvrdenie odovzdania spotrebného materiálu',
    'Confirm_license_delivery' => 'Potvrdenie priradenia licencie',
    'Consumable_checkout_notification' => 'Spotrebný materiál odovzdaný',
    'Days' => 'Dni',
    'Expected_Checkin_Date' => 'Majetok, ktorý vám bol odovzdaný, musí byť vrátený späť do :date',
    'Expected_Checkin_Notification' => 'Pripomienka: Termín na vrátenie :name sa blíži',
    'Expected_Checkin_Report' => 'Report očakávaných vrátení majetku',
    'Expiring_Assets_Report' => 'Report majetku s končiacou zárukou.',
    'Expiring_Licenses_Report' => 'Report exspirujúcich licencií.',
    'Item_Request_Canceled' => 'Požiadavka na položku zrušená',
    'Item_Requested' => 'Položka vyžiadaná',
    'License_Checkin_Notification' => 'Licencia odobratá',
    'License_Checkout_Notification' => 'Licencie priradená',
    'license_for'   => 'Licencia pre',
    'Low_Inventory_Report' => 'Report nízkych zásob',
    'a_user_canceled' => 'Používateľ zrušil žiadosť o položku na webe',
    'a_user_requested' => 'Používateľ vytvoril žiadosť o položku na webe',
    'acceptance_asset_accepted' => 'Používateľ potvrdil prijatie položky',
    'acceptance_asset_declined' => 'Používateľ zamietol prijatie položky',
    'accessory_name' => 'Názov príslušenstva',
    'additional_notes' => 'Ďalšie poznámky',
    'admin_has_created' => 'Administrátor pre vás vytvoril účet na stránke :web.',
    'asset' => 'Majetok',
    'asset_name' => 'Názov majetku',
    'asset_requested' => 'Vyžiadaný majetok',
    'asset_tag' => 'Označenie majetku',
    'assets_warrantee_alert' => 'Existuje :count položka majetku, ktorej končí záruka v najbližších :threshold dňoch.|Existuje :count položiek majetku, ktorým končí záruka v najbližších :threshold dňoch.',
    'assigned_to' => 'Pridelené',
    'best_regards' => 'S pozdravom,',
    'canceled' => 'Zrušené',
    'checkin_date' => 'Dátum vrátenia',
    'checkout_date' => 'Dátum odovzdania',
    'checkedout_from' => 'Odovzadené od',
    'checkedin_from'  => 'Prijaté od',
    'checked_into' => 'Priradené do',
    'click_on_the_link_accessory' => 'Prosím kliknite na nižšie priložený odkaz pre potvrdenie prevzatia príslušenstva.',
    'click_on_the_link_asset' => 'Prosím kliknite na nižšie priložený odkaz pre potvrdenie prevzatia majetku.',
    'click_to_confirm' => 'Prosím kliknite na nasledujúci odkaz pre potvrdenie vášho :web účtu:',
    'current_QTY' => 'Aktuálne množstvo',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očakávaný dátum vrátenia',
    'expires' => 'Exspiruje',
    'hello' => 'Ahoj',
    'hi' => 'Ahoj',
    'i_have_read' => 'Súhlasím s podmienkami používania, potvrdzujem prevzatie položky.',
    'inventory_report' => 'Report majetku',
    'item' => 'Položka',
    'item_checked_reminder' => 'Toto je pripomienka, že vám boli odovzdané :count položky, ktorých prijatie ste nepotvrdili a ani neodmietli. Prosím kliknite na odkaz nižšie pre potvrdenie vašej voľby.',
    'license_expiring_alert' => 'V nasledujúcich :threshold dňoch exspiruje :count licencia.|V nasledujúcich :threshold dňoch exspirujú :count licencie.',
    'link_to_update_password' => 'Prosím kliknite na nasledovný odkaz pre zmenu hesla na stránke :web :',
    'login' => 'Prihlásenie',
    'login_first_admin' => 'Prihláste sa do vašej novej Snipe-IT inštalácie s použitím prihlasovacích údajov:',
    'low_inventory_alert' => 'Existuje :count položka, ktorá je alebo čoskoro bude pod hranicou minimálnych skladových zásob.|Existuje :count položiek, ktoré sú alebo čoskoro budú pod hranicou minimálnych skladových zásob.',
    'min_QTY' => 'Minimálne množstvo',
    'name' => 'Názov',
    'new_item_checked' => 'bola ti odovzdaná nová položka, podrobnosti sú uvedené nižšie.',
    'notes' => 'Poznámky',
    'password' => 'Heslo',
    'password_reset' => 'Reset hesla',
    'read_the_terms' => 'Prosím prečítajte si nižšie uvedené podmienky používania.',
    'read_the_terms_and_click' => 'Prosím prečítajte si nižšie uvedené podmienky používania a kliknite na odkaz v dolnej časti pre potvrdenie, že ste si prečítali a súhlasili s podmienkami používania a prevzali majetok.',
    'requested' => 'Vyžiadané',
    'reset_link' => 'Váš odkaz na resetovanie hesla',
    'reset_password' => 'Kliknite sem pre resetovanie vášho hesla:',
    'rights_reserved' => 'Všetky práva vyhradené.',
    'serial' => 'Sériové číslo',
    'snipe_webhook_test' => 'Snipe-IT integračný test',
    'snipe_webhook_summary' => 'Snipe-IT výsledok integračného testu',
    'supplier' => 'Dodávateľ',
    'tag' => 'Značka',
    'test_email' => 'Testovací mail zo Snipe-IT',
    'test_mail_text' => 'Toto je test odoslaný zo Snipe-IT Asset Manažmentu. Všetko funguje, ak ste obdržali tento mail :)',
    'the_following_item' => 'nasledujúca položka bola vrátená: ',
    'to_reset' => 'Pre resetovanie vášho :web hesla, prosím vyplňte nasledujúci formulár:',
    'type' => 'Typ',
    'upcoming-audits' => 'Existuje :count položka, ktorá bude podliehať auditu v priebehu :threshold dní.|Existujú :count položky, ktoré budú podliehať auditu v priebehu :threshold dní.',
    'user' => 'Používateľ',
    'username' => 'Používateľské meno',
    'unaccepted_asset_reminder' => 'Nepotvrdili ste prevzatie majetku.',
    'welcome' => 'Vitaj :name',
    'welcome_to' => 'Vitaj na :web!',
    'your_assets' => 'Zobraziť vaše položky majetku',
    'your_credentials' => 'Vaše Snipe-IT prihlasovacie údaje',
    'mail_sent' => 'Mail bol úspešne odoslaný!',
];
